==> xfree86-1_3.3.6.orig.tar.gz: xc/programs/lbxproxy/include/init.h <==
/* $XConsortium: init.h /main/3 1996/12/03 14:22:04 kaleb $ */
/*
 * Copyright 1992 Network Computing Devices
 * Copyright 1996 X Consortium, Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of NCD. not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  NCD. makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * NCD. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL NCD.
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 */

#ifndef _INIT_H_
#define _INIT_H_

extern struct _XDisplay* DisplayOpen(
#if NeedFunctionPrototypes
    char * /*dpy_name*/,
    int * /*request*/,
    int * /*event*/,
    int * /*error*/,
    int * /*sequencep*/
#endif
);

extern int DisplayConnectionNumber(
#if NeedFunctionPrototypes
    struct _XDisplay* /* dpy */
#endif
);

extern void DisplayGetConnSetup (
#if NeedFunctionPrototypes
    struct _XDisplay* /* dpy */,
    xConnSetup** /* tag_data */,
    int* /* len */,
    int /* change_type */,
    CARD32* /* changes */,
    int /* change_len */
#endif
);

#endif

==> xfree86_4.1.0.orig.tar.gz: xc/programs/lbxproxy/include/init.h <==
/* $Xorg: init.h,v 1.3 2000/08/17 19:53:57 cpqbld Exp $ */
/*

Copyright 1996, 1998  The Open Group

All Rights Reserved.

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Except as contained in this notice, the name of The Open Group shall not be
used in advertising or otherwise to promote the sale, use or other dealings
in this Software without prior written authorization from The Open Group.

*/
/*
 * Copyright 1992 Network Computing Devices
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of NCD. not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  NCD. makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * NCD. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL NCD.
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 */

#ifndef _INIT_H_
#define _INIT_H_

extern struct _XDisplay* DisplayOpen(
#if NeedFunctionPrototypes
    char * /*dpy_name*/,
    int * /*request*/,
    int * /*event*/,
    int * /*error*/,
    int * /*sequencep*/
#endif
);

extern int DisplayConnectionNumber(
#if NeedFunctionPrototypes
    struct _XDisplay* /* dpy */
#endif
);

extern void DisplayGetConnSetup (
#if NeedFunctionPrototypes
    struct _XDisplay* /* dpy */,
    xConnSetup** /* tag_data */,
    int* /* len */,
    int /* change_type */,
    CARD32* /* changes */,
    int /* change_len */
#endif
);

#endif
